==> ejc-bid-impl-3.0.0-20221208.083005-294-sources.jar: com/ejianc/business/bid/bean/UndertakeEntity.java <==
package com.ejianc.business.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 承揽任务登记
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_undertake")
public class UndertakeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="operator_code")
    private String operatorCode; // 经办人联系方式
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="make_org_id")
    private Long makeOrgId; // 编制部门ID
    @TableField(value="make_org_name")
    private String makeOrgName; // 编制部门名称
    @TableField(value="make_time")
    private Date makeTime; // 编制时间
    @TableField(value="project_id")
    private Long projectId; // 工程id
    @TableField(value="porject_name")
    private String porjectName; // 工程名称
    @TableField(value="speciality_id")
    private Long specialityId; // 工程类别id
    @TableField(value="speciality_name")
    private String specialityName; // 工程类别类别名称
    @TableField(value="project_remark")
    private String projectRemark; // 工程概况
    @TableField(value="project_quality")
    private String projectQuality; // 工程质量
    @TableField(value="project_cost")
    private BigDecimal projectCost; // 工程造价
    @TableField(value="days")
    private BigDecimal days; // 工期（日历天）
    @TableField(value="jzs_id")
    private Long jzsId; // 建造师id
    @TableField(value="jzs_name")
    private String jzsName; // 建造师名称
    @TableField(value="xmnbcbr_id")
    private Long xmnbcbrId; // 项目内部承包人id
    @TableField(value="xmnbcbr_name")
    private String xmnbcbrName; // 项目内部承包人名称
    @TableField(value="sq_time")
    private Date sqTime; // 申请时间
    @TableField(value="zb_time")
    private Date zbTime; // 中标时间
    @TableField(value="htgzrq_time")
    private Date htgzrqTime; // 合同盖章时间
    @TableField(value="htbjrq_time")
    private Date htbjrqTime; // 合同办结时间
    @TableField(value="gzzt")
    private String gzzt; // 跟踪状态
    @TableField(value="xgsm")
    private String xgsm; // 相关说明
    @TableField(value="zjzmj")
    private BigDecimal zjzmj; // 总建筑面积
    @TableField(value="jgxs_id")
    private Long jgxsId; // 结构形式id
    @TableField(value="jgxs_name")
    private String jgxsName; // 结构形式
    @TableField(value="enroll_id")
    private Long enrollId; // 投标报名
    @TableField(value="contract_type")
    private String contractType; // 合同类型
    @TableField(value="contract_status")
    private String contractStatus; // 合同状态
    @TableField(value="zzje")
    private BigDecimal zzje; // 最终金额
    @TableField(value="year")
    private Integer year; // 年份
    @TableField(value="month")
    private Integer month; // 月份
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_code")
    private String contractCode; // 合同编号
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_money")
    private BigDecimal contractMoney; // 合同金额
    @TableField(value="org_code")
    private String orgCode; // 组织编号
    @TableField(value="yw_date")
    private Date ywDate; // 业务时间
    @TableField(value="area")
    private String area; // 地区
    @TableField(value="area_name")
    private String areaName; // 地区名称
    @TableField(value="speciality_code")
    private String specialityCode; // 工程类别类别编号
    @TableField(value="supplement_flag")
    private Integer supplementFlag; // 补充协议标识
    @TableField(value="main_id")
    private Long mainId; // 合同id


    public Long getMainId() {
        return mainId;
    }

    public void setMainId(Long mainId) {
        this.mainId = mainId;
    }

    public Integer getSupplementFlag() {
        return supplementFlag;
    }

    public void setSupplementFlag(Integer supplementFlag) {
        this.supplementFlag = supplementFlag;
    }

    public String getSpecialityCode() {
        return specialityCode;
    }

    public void setSpecialityCode(String specialityCode) {
        this.specialityCode = specialityCode;
    }

    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }

    public String getAreaName() {
        return areaName;
    }

    public void setAreaName(String areaName) {
        this.areaName = areaName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public Date getYwDate() {
        return ywDate;
    }

    public void setYwDate(Date ywDate) {
        this.ywDate = ywDate;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public BigDecimal getContractMoney() {
        return contractMoney;
    }

    public void setContractMoney(BigDecimal contractMoney) {
        this.contractMoney = contractMoney;
    }

    public Long getEnrollId() {
        return enrollId;
    }

    public void setEnrollId(Long enrollId) {
        this.enrollId = enrollId;
    }

    public String getContractType() {
        return contractType;
    }

    public void setContractType(String contractType) {
        this.contractType = contractType;
    }

    public String getContractStatus() {
        return contractStatus;
    }

    public void setContractStatus(String contractStatus) {
        this.contractStatus = contractStatus;
    }

    public BigDecimal getZzje() {
        return zzje;
    }

    public void setZzje(BigDecimal zzje) {
        this.zzje = zzje;
    }

    public Integer getYear() {
        return year;
    }

    public void setYear(Integer year) {
        this.year = year;
    }

    public Integer getMonth() {
        return month;
    }

    public void setMonth(Integer month) {
        this.month = month;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getOperatorCode() {
        return operatorCode;
    }

    public void setOperatorCode(String operatorCode) {
        this.operatorCode = operatorCode;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getMakeOrgId() {
        return makeOrgId;
    }

    public void setMakeOrgId(Long makeOrgId) {
        this.makeOrgId = makeOrgId;
    }
    public String getMakeOrgName() {
        return makeOrgName;
    }

    public void setMakeOrgName(String makeOrgName) {
        this.makeOrgName = makeOrgName;
    }
    public Date getMakeTime() {
        return makeTime;
    }

    public void setMakeTime(Date makeTime) {
        this.makeTime = makeTime;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getPorjectName() {
        return porjectName;
    }

    public void setPorjectName(String porjectName) {
        this.porjectName = porjectName;
    }
    public Long getSpecialityId() {
        return specialityId;
    }

    public void setSpecialityId(Long specialityId) {
        this.specialityId = specialityId;
    }
    public String getSpecialityName() {
        return specialityName;
    }

    public void setSpecialityName(String specialityName) {
        this.specialityName = specialityName;
    }
    public String getProjectRemark() {
        return projectRemark;
    }

    public void setProjectRemark(String projectRemark) {
        this.projectRemark = projectRemark;
    }
    public String getProjectQuality() {
        return projectQuality;
    }

    public void setProjectQuality(String projectQuality) {
        this.projectQuality = projectQuality;
    }
    public BigDecimal getProjectCost() {
        return projectCost;
    }

    public void setProjectCost(BigDecimal projectCost) {
        this.projectCost = projectCost;
    }
    public BigDecimal getDays() {
        return days;
    }

    public void setDays(BigDecimal days) {
        this.days = days;
    }
    public Long getJzsId() {
        return jzsId;
    }

    public void setJzsId(Long jzsId) {
        this.jzsId = jzsId;
    }
    public String getJzsName() {
        return jzsName;
    }

    public void setJzsName(String jzsName) {
        this.jzsName = jzsName;
    }
    public Long getXmnbcbrId() {
        return xmnbcbrId;
    }

    public void setXmnbcbrId(Long xmnbcbrId) {
        this.xmnbcbrId = xmnbcbrId;
    }
    public String getXmnbcbrName() {
        return xmnbcbrName;
    }

    public void setXmnbcbrName(String xmnbcbrName) {
        this.xmnbcbrName = xmnbcbrName;
    }
    public Date getSqTime() {
        return sqTime;
    }

    public void setSqTime(Date sqTime) {
        this.sqTime = sqTime;
    }
    public Date getZbTime() {
        return zbTime;
    }

    public void setZbTime(Date zbTime) {
        this.zbTime = zbTime;
    }
    public Date getHtgzrqTime() {
        return htgzrqTime;
    }

    public void setHtgzrqTime(Date htgzrqTime) {
        this.htgzrqTime = htgzrqTime;
    }
    public Date getHtbjrqTime() {
        return htbjrqTime;
    }

    public void setHtbjrqTime(Date htbjrqTime) {
        this.htbjrqTime = htbjrqTime;
    }
    public String getGzzt() {
        return gzzt;
    }

    public void setGzzt(String gzzt) {
        this.gzzt = gzzt;
    }
    public String getXgsm() {
        return xgsm;
    }

    public void setXgsm(String xgsm) {
        this.xgsm = xgsm;
    }
    public BigDecimal getZjzmj() {
        return zjzmj;
    }

    public void setZjzmj(BigDecimal zjzmj) {
        this.zjzmj = zjzmj;
    }
    public Long getJgxsId() {
        return jgxsId;
    }

    public void setJgxsId(Long jgxsId) {
        this.jgxsId = jgxsId;
    }
    public String getJgxsName() {
        return jgxsName;
    }

    public void setJgxsName(String jgxsName) {
        this.jgxsName = jgxsName;
    }
    
}

==> ejc-bid-impl-3.0.0-20231023.102317-387-sources.jar: com/ejianc/business/bid/bean/UndertakeEntity.java <==
package com.ejianc.business.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 承揽任务登记
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_undertake")
public class UndertakeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="operator_code")
    private String operatorCode; // 经办人联系方式
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="make_org_id")
    private Long makeOrgId; // 编制部门ID
    @TableField(value="make_org_name")
    private String makeOrgName; // 编制部门名称
    @TableField(value="make_time")
    private Date makeTime; // 编制时间
    @TableField(value="project_id")
    private Long projectId; // 工程id
    @TableField(value="porject_name")
    private String porjectName; // 工程名称
    @TableField(value="speciality_id")
    private Long specialityId; // 工程类别id
    @TableField(value="speciality_name")
    private String specialityName; // 工程类别类别名称
    @TableField(value="project_remark")
    private String projectRemark; // 工程概况
    @TableField(value="project_quality")
    private String projectQuality; // 工程质量
    @TableField(value="project_cost")
    private BigDecimal projectCost; // 工程造价
    @TableField(value="days")
    private BigDecimal days; // 工期（日历天）
    @TableField(value="jzs_id")
    private Long jzsId; // 建造师id
    @TableField(value="jzs_name")
    private String jzsName; // 建造师名称
    @TableField(value="xmnbcbr_id")
    private Long xmnbcbrId; // 项目内部承包人id
    @TableField(value="xmnbcbr_name")
    private String xmnbcbrName; // 项目内部承包人名称
    @TableField(value="sq_time")
    private Date sqTime; // 申请时间
    @TableField(value="zb_time")
    private Date zbTime; // 中标时间
    @TableField(value="htgzrq_time")
    private Date htgzrqTime; // 合同盖章时间
    @TableField(value="htbjrq_time")
    private Date htbjrqTime; // 合同办结时间
    @TableField(value="gzzt")
    private String gzzt; // 跟踪状态
    @TableField(value="xgsm")
    private String xgsm; // 相关说明
    @TableField(value="zjzmj")
    private BigDecimal zjzmj; // 总建筑面积
    @TableField(value="jgxs_id")
    private Long jgxsId; // 结构形式id
    @TableField(value="jgxs_name")
    private String jgxsName; // 结构形式
    @TableField(value="enroll_id")
    private Long enrollId; // 投标报名
    @TableField(value="contract_type")
    private String contractType; // 合同类型
    @TableField(value="contract_status")
    private String contractStatus; // 合同状态
    @TableField(value="zzje")
    private BigDecimal zzje; // 最终金额
    @TableField(value="year")
    private Integer year; // 年份
    @TableField(value="month")
    private Integer month; // 月份
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_code")
    private String contractCode; // 合同编号
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_money")
    private BigDecimal contractMoney; // 合同金额
    @TableField(value="org_code")
    private String orgCode; // 组织编号
    @TableField(value="yw_date")
    private Date ywDate; // 业务时间
    @TableField(value="area")
    private String area; // 地区
    @TableField(value="area_name")
    private String areaName; // 地区名称
    @TableField(value="speciality_code")
    private String specialityCode; // 工程类别类别编号
    @TableField(value="supplement_flag")
    private Integer supplementFlag; // 补充协议标识
    @TableField(value="main_id")
    private Long mainId; // 合同id


    public Long getMainId() {
        return mainId;
    }

    public void setMainId(Long mainId) {
        this.mainId = mainId;
    }

    public Integer getSupplementFlag() {
        return supplementFlag;
    }

    public void setSupplementFlag(Integer supplementFlag) {
        this.supplementFlag = supplementFlag;
    }

    public String getSpecialityCode() {
        return specialityCode;
    }

    public void setSpecialityCode(String specialityCode) {
        this.specialityCode = specialityCode;
    }

    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }

    public String getAreaName() {
        return areaName;
    }

    public void setAreaName(String areaName) {
        this.areaName = areaName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public Date getYwDate() {
        return ywDate;
    }

    public void setYwDate(Date ywDate) {
        this.ywDate = ywDate;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public BigDecimal getContractMoney() {
        return contractMoney;
    }

    public void setContractMoney(BigDecimal contractMoney) {
        this.contractMoney = contractMoney;
    }

    public Long getEnrollId() {
        return enrollId;
    }

    public void setEnrollId(Long enrollId) {
        this.enrollId = enrollId;
    }

    public String getContractType() {
        return contractType;
    }

    public void setContractType(String contractType) {
        this.contractType = contractType;
    }

    public String getContractStatus() {
        return contractStatus;
    }

    public void setContractStatus(String contractStatus) {
        this.contractStatus = contractStatus;
    }

    public BigDecimal getZzje() {
        return zzje;
    }

    public void setZzje(BigDecimal zzje) {
        this.zzje = zzje;
    }

    public Integer getYear() {
        return year;
    }

    public void setYear(Integer year) {
        this.year = year;
    }

    public Integer getMonth() {
        return month;
    }

    public void setMonth(Integer month) {
        this.month = month;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getOperatorCode() {
        return operatorCode;
    }

    public void setOperatorCode(String operatorCode) {
        this.operatorCode = operatorCode;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getMakeOrgId() {
        return makeOrgId;
    }

    public void setMakeOrgId(Long makeOrgId) {
        this.makeOrgId = makeOrgId;
    }
    public String getMakeOrgName() {
        return makeOrgName;
    }

    public void setMakeOrgName(String makeOrgName) {
        this.makeOrgName = makeOrgName;
    }
    public Date getMakeTime() {
        return makeTime;
    }

    public void setMakeTime(Date makeTime) {
        this.makeTime = makeTime;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getPorjectName() {
        return porjectName;
    }

    public void setPorjectName(String porjectName) {
        this.porjectName = porjectName;
    }
    public Long getSpecialityId() {
        return specialityId;
    }

    public void setSpecialityId(Long specialityId) {
        this.specialityId = specialityId;
    }
    public String getSpecialityName() {
        return specialityName;
    }

    public void setSpecialityName(String specialityName) {
        this.specialityName = specialityName;
    }
    public String getProjectRemark() {
        return projectRemark;
    }

    public void setProjectRemark(String projectRemark) {
        this.projectRemark = projectRemark;
    }
    public String getProjectQuality() {
        return projectQuality;
    }

    public void setProjectQuality(String projectQuality) {
        this.projectQuality = projectQuality;
    }
    public BigDecimal getProjectCost() {
        return projectCost;
    }

    public void setProjectCost(BigDecimal projectCost) {
        this.projectCost = projectCost;
    }
    public BigDecimal getDays() {
        return days;
    }

    public void setDays(BigDecimal days) {
        this.days = days;
    }
    public Long getJzsId() {
        return jzsId;
    }

    public void setJzsId(Long jzsId) {
        this.jzsId = jzsId;
    }
    public String getJzsName() {
        return jzsName;
    }

    public void setJzsName(String jzsName) {
        this.jzsName = jzsName;
    }
    public Long getXmnbcbrId() {
        return xmnbcbrId;
    }

    public void setXmnbcbrId(Long xmnbcbrId) {
        this.xmnbcbrId = xmnbcbrId;
    }
    public String getXmnbcbrName() {
        return xmnbcbrName;
    }

    public void setXmnbcbrName(String xmnbcbrName) {
        this.xmnbcbrName = xmnbcbrName;
    }
    public Date getSqTime() {
        return sqTime;
    }

    public void setSqTime(Date sqTime) {
        this.sqTime = sqTime;
    }
    public Date getZbTime() {
        return zbTime;
    }

    public void setZbTime(Date zbTime) {
        this.zbTime = zbTime;
    }
    public Date getHtgzrqTime() {
        return htgzrqTime;
    }

    public void setHtgzrqTime(Date htgzrqTime) {
        this.htgzrqTime = htgzrqTime;
    }
    public Date getHtbjrqTime() {
        return htbjrqTime;
    }

    public void setHtbjrqTime(Date htbjrqTime) {
        this.htbjrqTime = htbjrqTime;
    }
    public String getGzzt() {
        return gzzt;
    }

    public void setGzzt(String gzzt) {
        this.gzzt = gzzt;
    }
    public String getXgsm() {
        return xgsm;
    }

    public void setXgsm(String xgsm) {
        this.xgsm = xgsm;
    }
    public BigDecimal getZjzmj() {
        return zjzmj;
    }

    public void setZjzmj(BigDecimal zjzmj) {
        this.zjzmj = zjzmj;
    }
    public Long getJgxsId() {
        return jgxsId;
    }

    public void setJgxsId(Long jgxsId) {
        this.jgxsId = jgxsId;
    }
    public String getJgxsName() {
        return jgxsName;
    }

    public void setJgxsName(String jgxsName) {
        this.jgxsName = jgxsName;
    }

    @Override
    public String toString() {
        return "UndertakeEntity{" +
                "billCode='" + billCode + '\'' +
                ", orgId=" + orgId +
                ", orgName='" + orgName + '\'' +
                ", billState=" + billState +
                ", makeOrgId=" + makeOrgId +
                ", makeOrgName='" + makeOrgName + '\'' +
                ", makeTime=" + makeTime +
                ", projectId=" + projectId +
                ", porjectName='" + porjectName + '\'' +
                ", ywDate=" + ywDate +
                '}';
    }
}
